# Dihedral group of order 2*(2^t*u), t >= 2, u odd
ExampleDihedral := function(t, u, class, print)
local F, R, n, r, s;

    n := 2^t*u;
    
    F := FreeGroup(2);
    r := F.1; s := F.2;
    R := [ r^n, s^2, s*r*s*r ];

    return AugmentationQuotientFpGroup(F/R, class, print);
end;


# Infinite dihedral group
ExampleInfiniteDihedral := function(class, print)
local F, R, a, b;

    F := FreeGroup(2);
    a := F.1; b := F.2;
    R := [ a^2, a^-1*b*a*b ];
    
    return AugmentationQuotientFpGroup(F/R, class, print);
end;


# Semidihedral group of order 2^k
ExampleSemidihedral := function(k, class, print)
local F, R, a, b;
    
    F := FreeGroup(2);
    a := F.1; b := F.2;
    R := [ a^(2^(k-1)), b^2, b^-1*a^-1*b*a^(-1+2^(k-2)) ];
    
    return AugmentationQuotientFpGroup(F/R, class, print);
end;


# Generalized quaternion groups for even m
ExampleQuaternionEven := function(t, l, class, print)
local F, R, m, a, b;

    m := 2^t*l;
    
    F := FreeGroup(2);
    a := F.1; b := F.2;
    R := [ a^(2*m), a^m*b^-2, b^-1*a*b*a ];
    
    return AugmentationQuotientFpGroup(F/R, class, print);
end;


# Generalized quaternion groups for odd m
ExampleQuaternionOdd := function(m, class, print)
local F, R, a, b;

    F := FreeGroup(2);
    a := F.1; b := F.2;
    R := [ a^(2*m), b^2*a^-m, b^-1*a*b*a ];
    
    return AugmentationQuotientFpGroup(F/R, class, print);
end;


# G_16 from Zhou 2009
ExampleG16 := function( class, print )
local F, R, x, y, z;
    
    F := FreeGroup(3);
    x := F.1; y := F.2; z := F.3;
    R := [ x^4, y^4, z^2, y*x*y^-1*x^-1, z*y*z^-1*y^-1, x*z*x^-1*y^-2*z^-1 ];
    
    return AugmentationQuotientFpGroup(F/R, class, print);
end;


# G_21 from Zhou 2009
ExampleG21 := function( class, print )
local F, R, x, y;
    
    F := FreeGroup(2);
    x := F.1; y := F.2;
    R := [ x^4, y^8, x*y*x*y^-1 ];
    
    return AugmentationQuotientFpGroup(F/R, class, print);
end;


# G_34 from Zhou 2009
ExampleG34 := function( class, print )
local F, R, x, y, z;
    
    F := FreeGroup(3);
    x := F.1; y := F.2; z := F.3;
    R := [ x^4, y^4, z^2, x*y*x^-1*y^-1, x*z*x*z^-1, y*z*y*z^-1 ];
    
    return AugmentationQuotientFpGroup(F/R, class, print);
end;


# G_46 from Zhou 2009
ExampleG46 := function( class, print )
local F, R, u, x, y, z;
    
    F := FreeGroup(4);
    u := F.1; x := F.2; y := F.3; z := F.4;
    R := [ u^2, x^4, y^2, z^2, x^-1*z^-1*x*u*z, x^-1*y^-1*x*u*z*y, u^-1*x^-1*u*x, u^-1*y^-1*u*y, u^-1*z^-1*u*z, y^-1*z^-1*y*z]; 

    return AugmentationQuotientFpGroup(F/R, class, print);
end;


# Heisenberg group on 2n+1 generators
ExampleHeisenberg := function( n, class, print )
local H;

    H := HeisenbergPcpGroup(n);
    H := PcpGroupToFpGroup(H);

    return AugmentationQuotientFpGroup(H, class, print);
end;


# Baumslag Solitar groups
ExampleBSGroup := function( m, n, class, print )
local F, a, b, R;
  
    F := FreeGroup(2);
    a := F.1; b := F.2;
    R := [b*a^m*b^-1*a^-n];

    return AugmentationQuotientFpGroup(F/R, class, print);
end;

