#############################################################################
##
#W  helper.gi             zalgs package                   Tobias Moede
##
#W Contains helper functions that are used throughout the package.


###################################################################### 
##
#F ZAlgsVecSingleOne( <n>, <pos> )
##  
## Builds a list of length 'n' containing only zeroes, except for a single
## one at position 'pos'

ZAlgsVecSingleOne := function( n, pos )
local ret;

    ret := ListWithIdenticalEntries(n, 0);
    ret[pos] := 1;
    
    return ret;
end;


######################################################################
##
#F ZAlgsDepthVector( <vec> )
##  
## Returns the first non-zero position of 'vec' and Length(vec)+1 if
## 'vec' is a list of zeroes

ZAlgsDepthVector := function ( vec )
local  i;
    for i  in [ 1 .. Length( vec ) ]  do
        if vec[i] <> 0 * vec[i]  then
            return i;
        fi;
    od;
    return Length( vec ) + 1;
end;


###################################################################### 
##
#F ZAlgsPositionsNonzero( <vec> )
##  
## Returns the non-zero positions of 'vec'

ZAlgsPositionsNonzero := function( vec )
local pos, i;
    
    pos := [];

    for i in [1..Length(vec)] do
        if vec[i] <> 0*vec[i] then 
            Add(pos, i);
        fi;
    od;

    return pos;
end;


######################################################################
##
#F ZAlgsIsZeroVec( <vec> )
##  
## Returns true if 'vec' contains zeroes, false otherwise

ZAlgsIsZeroVec := function( vec )
    return ZAlgsDepthVector(vec) > Length(vec);
end;


######################################################################
##
#F ZAlgsFindInTwoDim( <M>, <x> )
##  
## Returns the first position of 'x' in the two-dimensional list 'M' or
## fail if M does not contain M

ZAlgsFindInTwoDim := function( M, x )
local i, j;
    
    for i in [1..Length(M)] do
        for j in [1..Length(M)] do
            if M[i][j]=x then
                return [i,j];
            fi;
        od;
    od;

    return fail;
end;
