#############################################################################
##
#W  print.gi             zalgs package                   Tobias Moede
##
#W Contains functions for printing presentations of calculated nilpotent quotients
#W and the structure of their augmentation quotients.


###################################################################### 
##
#F ZAlgsPrintPresentation( <T> )
##  
## Prints all non-trivial relations for the nilpotent quotient 'T'

InstallMethod( 
        PrintPresentationFpZAlgebraNQ,
        "for pcp-groups",
        [ IsRecord ],
        function( T )

local str, i, j, k;

    Print("# weights: \n");
    Print(T.wgs, "\n");

    Print("\n# powers: \n");
    Print(T.pows, "\n");

    Print("\n# definitions: \n");
    Print(T.dfs, "\n");

    Print("\n# power relations: \n");

    for i in [1..Length(T.ptab)] do
        str := Concatenation(String(T.pows[i]), "b_", String(i), " = ");
        
        for j in [1..Length(T.ptab[i])] do
            if T.ptab[i][j] <> 0 then              
                str := Concatenation(str, "b_", String(j), " + ");
            fi;
        od;

        if str{[Length(str)-2..Length(str)]} = " + " then
            Remove(str); Remove(str); Remove(str);
        fi;

        if str[Length(str)] <> ' ' then
		    Print(str, "\n");
        fi;
    od;

    Print("\n# multiplication relations: \n");
    for i in [1..T.dim] do
        for j in [1..T.dim] do
            str := Concatenation("b_", String(i), " b_", String(j), " = ");
            for k in [1..Length(T.mtab[i][j])] do
                if T.mtab[i][j][k] <> 0 then              
                    str := Concatenation(str, "b_", String(k), " + ");
                fi;
            od;

            if str{[Length(str)-2..Length(str)]} = " + " then
			    Remove(str); Remove(str); Remove(str);
            fi;

            if str[Length(str)] <> ' ' then
			    Print(str, "\n");
            fi;
        od;
    od;
end );


###################################################################### 
##
#F ZAlgsPrintAugmentationQuotient( <quot>, <i> )
##  
## Prints presentation of quotient I^i/I^i+1 for a given quotient I/I^c+1.

ZAlgsPrintAugmentationQuotient := function( quot, i )
local pos, ptab, pows, str, j, k;

    if i > quot.wgs[Length(quot.wgs)] then
        Error("Quotient I^", i, "/I^", i+1, " is not contained in the calculated quotient.");
    fi;

    pos := Positions(quot.wgs, i);
    ptab := StructuralCopy(quot.ptab);
       
    # write powers
    for j in pos do
        ptab[j][j] := quot.pows[j];
    od;

    # cut and calculate smith normal form
    ptab := ptab{pos}{pos};
    ptab := SmithNormalFormIntegerMat(ptab);

    # read off powers
    pows := List([1..Length(ptab)], x -> ptab[x][x]);
    pows := Collected(pows);

    # construct string
    str := Concatenation("Q_", String(i), " = ");        

    for k in [1..Length(pows)] do
        if pows[k][1] = 0 then
            str := Concatenation(str, "Z^", String(pows[k][2]), " + ");
        elif pows[k][1] <> 1 then
            str := Concatenation(str, "Z_", String(pows[k][1]), "^", String(pows[k][2]), " + ");
        fi;
    od;

    str := str{[1..Length(str)-3]};
        
    Print(str, "\n");
end;


###################################################################### 
##
#F ZAlgsPrintAugmentationQuotients( <quot> )
##  
## Prints the quotients I^i/I^i+1, 1 <= i <= c for a given quotient I/I^c+1.

ZAlgsPrintAugmentationQuotients := function( quot )
local maxw, i, j, k, pos, pows, str, ptab;

    maxw := Maximum(quot.wgs);

    for i in [1..maxw] do
        pos := Positions(quot.wgs, i);
        ptab := StructuralCopy(quot.ptab);
       
        # write powers
        for j in pos do
            ptab[j][j] := quot.pows[j];
        od;

        # cut and calculate smith normal form
        ptab := ptab{pos}{pos};
        ptab := SmithNormalFormIntegerMat(ptab);

        # read off powers
        pows := List([1..Length(ptab)], x -> ptab[x][x]);
        pows := Collected(pows);

        # construct string
        str := Concatenation("Q_", String(i), " = ");        

        for k in [1..Length(pows)] do
            if pows[k][1] = 0 then
                str := Concatenation(str, "Z^", String(pows[k][2]), " + ");
            elif pows[k][1] <> 1 then
                str := Concatenation(str, "Z_", String(pows[k][1]), "^", String(pows[k][2]), " + ");
            fi;
        od;

        str := str{[1..Length(str)-3]};
        
        Print(str, "\n");
    od;
end;
